ete2.phylo.evolevents

Package ete2 :: Package phylo :: Module evolevents |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.phylo.evolevents

     1  __VERSION__="ete2-2.0rev90"
     2  # #START_LICENSE###########################################################
     3  #
     4  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     5  # email: jhcepas@gmail.com
     6  #
     7  # This file is part of the Environment for Tree Exploration program (ETE).
     8  # http://ete.cgenomics.org
     9  #
    10  # ETE is free software: you can redistribute it and/or modify it
    11  # under the terms of the GNU General Public License as published by
    12  # the Free Software Foundation, either version 3 of the License, or
    13  # (at your option) any later version.
    14  #
    15  # ETE is distributed in the hope that it will be useful,
    16  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    17  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    18  # GNU General Public License for more details.
    19  #
    20  # You should have received a copy of the GNU General Public License
    21  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    22  #
    23  # #END_LICENSE#############################################################
    24
    25  __all__ = ["EvolEvent"]
    26
    27 -class EvolEvent:
    28      """ Basic evolutionary event. It stores all the information about an
    29      event(node) ocurred in a phylogenetic tree. """
    30 -    def __init__(self):
    31          self.etype         = None   # 'S=speciation D=duplication'
    32          self.in_seqs       = []
    33          self.out_seqs      = []
    34          self.dup_score     = None
    35          self.sos           = None
    36
    37          # Not documented
    38          self.inparalogs    = None
    39          self.outparalogs   = None
    40          self.outgroup_spcs = None   # outgroup
    41          self.e_newick      = None   #
    42          self.root_age      = None   # estimated time for the outgroup node
    43          self.orthologs     = None
    44          self.famSize       = None
    45          self.seed          = None   # Seed ID used to start the phylogenetic pipeline
    46          self.branch_supports  = []
    47